<?xml version="1.0" encoding="UTF-8"?>
<ctl:package xmlns:ctl="http://www.occamlab.com/ctl"
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  xmlns:tns="http://www.opengis.net/cite/iso19142"
  xmlns:saxon="http://saxon.sf.net/"
  xmlns:tec="java:com.occamlab.te.TECore">

  <ctl:function name="tns:run-ets-wfs">
    <ctl:param name="testRunArgs">A Document node containing test run arguments (as XML properties).</ctl:param>
    <ctl:return>The test results as a Source object (root node).</ctl:return>
    <ctl:description>Runs the WFS 2.0 (iso19142 2.0-r7) test suite.</ctl:description>
    <ctl:java class="org.opengis.cite.iso19142.TestNGController" 
                  method="doTestRun" 
                  initialized="true">
      <ctl:with-param name="outputDirPath" select="system-property('java.io.tmpdir')" />
    </ctl:java>
  </ctl:function>

  <ctl:suite name="tns:ets-wfs-2.0-r7">
    <ctl:title>WFS 2.0 (ISO 19142:2010) Conformance Test Suite</ctl:title>
    <ctl:description>Checks WFS 2.0 implementations for conformance to ISO 19142:2010.</ctl:description>
    <ctl:starting-test>tns:Main</ctl:starting-test>
  </ctl:suite>

  <ctl:test name="tns:Main">
    <ctl:assertion>The test subject satisfies all applicable constraints.</ctl:assertion>
    <ctl:code>
      <xsl:variable name="form-data">
        <ctl:form method="POST" width="800" height="600" xmlns="http://www.w3.org/1999/xhtml">
          <h2>ISO 19142:2010 (WFS 2.0) Conformance Test Suite</h2>
          <div class="scope" 
			      style="background:#F0F8FF" bgcolor="#F0F8FF">
            <p>The WFS implementation is checked against the following specifications:</p>
            <ul>
              <li><a href="http://www.iso.org/iso/iso_catalogue/catalogue_tc/catalogue_detail.htm?csnumber=42136" 
                   target="_blank">ISO 19142:2010</a>, Geographic information -- Web Feature Service</li>
              <li><a href="http://www.iso.org/iso/iso_catalogue/catalogue_tc/catalogue_detail.htm?csnumber=42137" 
                   target="_blank">ISO 19143:2010</a>, Geographic information -- Filter encoding</li>
            </ul>
            <p>Four fundamental conformance levels are defined; the content of the capabilities document 
            will determine which of the following conformance levels are tested:</p>
            <ol>
              <li>Simple WFS</li>
              <li>Basic WFS</li>
              <li>Transactional WFS</li>
              <li>Locking WFS</li>
            </ol>
          </div>
          <fieldset style="background:#ccffff">
            <legend style="font-family: sans-serif; color: #000099; 
			   background-color:#F0F8FF; border-style: solid; border-width: medium; padding:4px">
			   Implementation under test</legend>
            <p>
              <label class="form-label" for="wfs">
                <h4 style="margin-bottom: 0.5em">Location of capabilities document (http: or file: URI)</h4>
              </label>
              <input id="wfs" name="wfs" size="96" type="text" value="" />
            </p>
          </fieldset>
          <p>
            <input class="form-button" type="submit" value="Start"/>
            <input class="form-button" type="reset" value="Clear"/>
          </p>
        </ctl:form>
      </xsl:variable>
      <xsl:variable name="test-run-props">
        <properties version="1.0">
          <entry key="wfs"><xsl:value-of select="$form-data/values/value[@key='wfs']"/></entry>
        </properties>
      </xsl:variable>
      <xsl:variable name="test-results">
        <ctl:call-function name="tns:run-ets-wfs">
          <ctl:with-param name="testRunArgs" select="$test-run-props"/>
        </ctl:call-function>
      </xsl:variable>
      <xsl:variable name="testRunDir">
        <xsl:value-of select="tec:getTestRunDirectory($te:core)"/>
      </xsl:variable>
      <xsl:call-template name="tns:testng-report">
        <xsl:with-param name="results" select="$test-results" />
        <xsl:with-param name="outputDir" select="$testRunDir" />
      </xsl:call-template>

      <xsl:variable name="total-failed" as="xs:integer">
        <xsl:value-of select="$test-results/testng-results/@failed"/>
      </xsl:variable>
      <ctl:message>
====================
Test results summary
====================
Failed: <xsl:value-of select="$total-failed"/>
Skipped: <xsl:value-of select="$test-results/testng-results/@skipped"/>
Passed: <xsl:value-of select="$test-results/testng-results/@passed"/>
--------------------

See detailed test report in the TE_BASE/users/<xsl:value-of 
select="concat(substring-after($testRunDir, 'users/'), '/html/')" /> directory.
      </ctl:message>
      <xsl:if test="$total-failed gt 0">
        <xsl:for-each select="$test-results//test-method[@status='FAIL' and @description='prerequisite']">
          <ctl:message>
Test prerequisite <xsl:value-of select="./@name"/> failed: <xsl:value-of select=".//message"/>
          </ctl:message>
        </xsl:for-each>
        <xsl:for-each select="$test-results//test-method[@status='FAIL' and not(@is-config='true')]">
          <ctl:message>
-----------
Test method <xsl:value-of select="./@name"/>: <xsl:value-of select=".//message"/>
          </ctl:message>
        </xsl:for-each>
        <ctl:fail/>
      </xsl:if>
    </ctl:code>
  </ctl:test>

  <xsl:template name="tns:testng-report">
    <xsl:param name="results" />
    <xsl:param name="outputDir" />
    <xsl:variable name="stylesheet" select="tec:findXMLResource($te:core, '/testng-report.xsl')" />
    <xsl:variable name="reporter" select="saxon:compile-stylesheet($stylesheet)" />
    <xsl:variable name="report-params" as="node()*">
      <xsl:element name="testNgXslt.outputDir">
        <xsl:value-of select="concat($outputDir, '/html')" />
      </xsl:element>
    </xsl:variable>
    <xsl:copy-of select="saxon:transform($reporter, $results, $report-params)" />
  </xsl:template>
</ctl:package>
